summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/enum.h
diff options
context:
space:
mode:
authordolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-06-18 16:00:35 +0000
committerdolorous <dolorous@c06c8d41-db1a-0410-9941-cceddc491573>2008-06-18 16:00:35 +0000
commitfdb1f24de9d264bac9001fd211ddb1a1ee7bc3dd (patch)
treea3ce30abeae78739d579e24a8410e5f14028b598 /crawl-ref/source/enum.h
parent970609327ec549152f3656d1f703efa4d62a7bb1 (diff)
downloadcrawl-ref-fdb1f24de9d264bac9001fd211ddb1a1ee7bc3dd.tar.gz
crawl-ref-fdb1f24de9d264bac9001fd211ddb1a1ee7bc3dd.zip
Reenable level-leaving monsters' using shaft traps again, properly this
time, and clean up a few related bits. Note that such monsters don't properly disappear yet after falling through shafts. git-svn-id: https://crawl-ref.svn.sourceforge.net/svnroot/crawl-ref/trunk@5946 c06c8d41-db1a-0410-9941-cceddc491573
Diffstat (limited to 'crawl-ref/source/enum.h')
-rw-r--r--crawl-ref/source/enum.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/crawl-ref/source/enum.h b/crawl-ref/source/enum.h
index bbdfad70a9..2457766b59 100644
--- a/crawl-ref/source/enum.h
+++ b/crawl-ref/source/enum.h
@@ -2790,7 +2790,8 @@ enum montravel_target_type
MTRAV_PLAYER, // Travelling to reach the player.
MTRAV_PATROL, // Travelling to reach the patrol point.
MTRAV_UNREACHABLE, // Not travelling because player is unreachable.
- MTRAV_EXIT // Travelling to reach a level exit.
+ MTRAV_EXIT, // Travelling to reach a level exit.
+ MTRAV_TRAP // Travelling to reach a trap.
};
#ifdef WIZARD